==> haskell-protolude-0.1.10-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-protolude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: protolude
version: 0.1.10
id: protolude-0.1.10-HtUCWfgcPoYAUczkJwv39V
key: protolude-0.1.10-HtUCWfgcPoYAUczkJwv39V
license: MIT
copyright: 2016 Stephen Diehl
maintainer: stephen.m.diehl@gmail.com
homepage: https://github.com/sdiehl/protolude
synopsis: A sensible set of defaults for writing custom Preludes.
description:
    A sensible set of defaults for writing custom Preludes.
category: Prelude
author: Stephen Diehl
exposed: True
exposed-modules:
    Protolude Unsafe Base Applicative Bool Debug List Monad Show Conv
    Either Functor Semiring Bifunctor Exceptions Panic
abi: a454616d2d1df1fe66b30866af722fff
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/protolude-0.1.10
library-dirs: /usr/lib/ghc-8.0.1/site-local/protolude-0.1.10
data-dir: /usr/share/i386-linux-ghc-8.0.1/protolude-0.1.10
hs-libraries: HSprotolude-0.1.10-HtUCWfgcPoYAUczkJwv39V
depends:
    async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4 base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1 deepseq-1.4.2.0
    ghc-prim-0.5.0.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    safe-0.3.14-ALdwhNEer7fKnF5VYCbXfH
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-protolude/html/protolude.haddock
haddock-html: /usr/share/doc/haskell-protolude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-protolude-0.1.10-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-protolude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: protolude
version: 0.1.10
id: protolude-0.1.10-9rOVLC4pXTVA5LjAjLDTtF
key: protolude-0.1.10-9rOVLC4pXTVA5LjAjLDTtF
license: MIT
copyright: 2016 Stephen Diehl
maintainer: stephen.m.diehl@gmail.com
homepage: https://github.com/sdiehl/protolude
synopsis: A sensible set of defaults for writing custom Preludes.
description:
    A sensible set of defaults for writing custom Preludes.
category: Prelude
author: Stephen Diehl
exposed: True
exposed-modules:
    Protolude Unsafe Base Applicative Bool Debug List Monad Show Conv
    Either Functor Semiring Bifunctor Exceptions Panic
abi: 6ceb09a1b85952fde756086bf3c58516
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/protolude-0.1.10
library-dirs: /usr/lib/ghc-8.0.1/site-local/protolude-0.1.10
data-dir: /usr/share/i386-linux-ghc-8.0.1/protolude-0.1.10
hs-libraries: HSprotolude-0.1.10-9rOVLC4pXTVA5LjAjLDTtF
depends:
    async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4 base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1 deepseq-1.4.2.0
    ghc-prim-0.5.0.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    safe-0.3.14-ALdwhNEer7fKnF5VYCbXfH
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-protolude/html/protolude.haddock
haddock-html: /usr/share/doc/haskell-protolude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
